# console_log/config.py


def read_config(path):
    blocks = []
    current = {}

    with open(path, 'r') as f:
        for line in f:
            line = line.strip()
            if not line:
                if current:
                    current["source_path"] = path
                    blocks.append(current)
                    current = {}
                continue
            if line.startswith("tty "):
                current["tty"] = line.split()[1]
            elif line.startswith("chvt "):
                current["chvt"] = line.split()[1].lower() == "yes"
            elif line.startswith("file "):
                current["file"] = line.split()[1:]
            elif line.startswith("group "):
                current["group"] = line.split()[1]
        if current:
            blocks.append(current)
    return blocks



import importlib


class RunPager:
    def __init__(self, path: str, config, pager: str = "less"):
        self.path = path
        self.pager = pager
        self.impl = self._load_pager()
        self.impl.run(self.path, config)

    def _load_pager(self):
        try:
            module_path = f"console_log.pagers.{self.pager}"
            class_name = f"{self.pager.capitalize()}Pager"
            module = importlib.import_module(module_path)
            cls = getattr(module, class_name)
            return cls()
        except (ModuleNotFoundError, AttributeError) as e:
            raise ValueError(f"Unknown pager '{self.pager}': {e}")



import subprocess
import os
import sys


class LessPager:
    def run(self, path: str, config):
        os.environ["LESSSECURE"] = (
            str(config.get("less_lesssecure") or "1")
        )
        os.environ["TERM"] = (
            config.get("less_term") or "linux"
        )
        os.environ["LESS"] = (
            config.get("less_opts")
            or "--LONG-PROMPT --chop-long-lines --IGNORE-CASE "
            "--jump-target=10 --max-forw-scroll=100 --window=-4 "
            "--status-column"
        )
        if config.get("less_follow_name"):
            os.environ["LESS"] = \
                os.environ.get("LESS", "") + " --follow-name"
        lesskey = (
            config.get("less_lesskey")
            or "/usr/share/console-log/lesskey"
        )
        if os.path.exists(lesskey):
            os.environ["LESSKEY"] = lesskey
        try:
            subprocess.run(
                [
                    "less",
                    f"-Pw\"less {path}\"",
                    "+F",
                    path
                ],
                check=True,
            )
        except FileNotFoundError:
            print(
                "Error: 'less' command not found.",
                "Please make sure it is installed.",
                file=sys.stderr,
            )
        except subprocess.CalledProcessError as e:
            print(
                f"Error: 'less' exited with code {e.returncode}",
                file=sys.stderr,
            )
